<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Show Address Book';
$labels['compose_addressbook_title'] = 'Address Book';
$labels['compose_addressbook_close'] = 'Close';
$labels['compose_addressbook_noselect'] = 'You did not select an address';
$labels['compose_addressbook_added'] = 'Addresses added';

?>
