<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Voeg adres uit adresboek toe';
$labels['compose_addressbook_title'] = 'Adres boek';
$labels['compose_addressbook_close'] = 'Sluiten';
$labels['compose_addressbook_noselect'] = 'Er is geen contact adres geselecteerd';
$labels['compose_addressbook_added'] = 'Adressen zijn toegevoegd';

?>
