<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Mostrar Direcciones';
$labels['compose_addressbook_title'] = 'Libreta de Direcciones';
$labels['compose_addressbook_close'] = 'Cerrar';
$labels['compose_addressbook_noselect'] = 'No has seleccionado ninguna dirección!';
$labels['compose_addressbook_added'] = 'Dirección añadida';

?>
