<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Adressbuch anzeigen';
$labels['compose_addressbook_title'] = 'Adressbuch';
$labels['compose_addressbook_close'] = 'Schließen';
$labels['compose_addressbook_noselect'] = 'Sie haben keine Adresse ausgewählt';
$labels['compose_addressbook_added'] = 'Adresse wurde hinzugefügt';


?>