<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Visa adressbok';
$labels['compose_addressbook_title'] = 'Adressbok';
$labels['compose_addressbook_close'] = 'Stäng';
$labels['compose_addressbook_noselect'] = 'Ingen adress valdes';
$labels['compose_addressbook_added'] = 'Adress tillagd';

?>
