<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Mostra la rubrica';
$labels['compose_addressbook_title'] = 'Rubrica';
$labels['compose_addressbook_close'] = 'Chiudi';
$labels['compose_addressbook_noselect'] = 'Non hai selezionato nessun indirizzo';
$labels['compose_addressbook_added'] = 'L\'indirizzo è stato aggiunto';

?>
