<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Afficher le carnet d\'adresse';
$labels['compose_addressbook_title'] = 'Carnet d\'adresse';
$labels['compose_addressbook_close'] = 'Fermer';
$labels['compose_addressbook_noselect'] = 'Vous n\'avez pas sélectionné d\'adresse';
$labels['compose_addressbook_added'] = 'Adresses ajoutées';

?>
