<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = '顯示地址簿';
$labels['compose_addressbook_title'] = '地址簿';
$labels['compose_addressbook_close'] = '關閉';
$labels['compose_addressbook_noselect'] = '沒有選擇電郵地址';
$labels['compose_addressbook_added'] = '已加入電郵地址';

?>