<?php

$labels = array();
$labels['compose_addressbook_buttontitle'] = 'Zobacz książkę adresową';
$labels['compose_addressbook_title'] = 'Książka adresowa';
$labels['compose_addressbook_close'] = 'Zamknij';
$labels['compose_addressbook_noselect'] = 'Zaznacz jakiś adres';
$labels['compose_addressbook_added'] = 'Adres został dodany';

?>
